

# DocTable Python Package

Document database interface for text analysis.

See the [doctable website](https://devinjcornell.com/doctable/) for documentation and examples.

Created by [Devin J. Cornell](https://devinjcornell.com).


### Thanks

The setup of this package was created following [this guide](https://packaging.python.org/tutorials/packaging-projects/).
